
/* Resume after suspension */

#include "sssd.h"
#include "internals.h"

INLINE_PROTO int Log2(int value);

int sssd_resume(struct sssdaudio *ga, const char* device_name) {

    int format, stereo, speed, fragsize;

    /* Setup audio device */
    if(device_name==DEFAULT_DEVICE)
       ga->audio_fd = open( DEFAULT_DEVICE_NAME, O_WRONLY, 0 );
    else 
       ga->audio_fd = open( device_name, O_WRONLY, 0 );
       
    if(ga->audio_fd== -1) {
    /* Opening default device failed */  
       #ifndef __NOPRINTING__
       perror( device_name );
       #endif
       ga->lastERR=ERR_DEVICE_RESUME;
       return( ERR_DEVICE_RESUME );
    }

    /* Setup device parameters */
    if(ga->bits==16) {
       format = AFMT_S16_LE;
    } else {
       format = AFMT_S8;
    }
    
    stereo   = 0;
    if(ga->channels!=1) stereo = 1;
    speed    = ga->freq;


    /* Program audio device with parameters */
    if(ga->audioBufferSize!=0) {
       fragsize=Log2(ga->audioBufferSize)|0x00040000;
#ifndef __NOPRINTING__
       printf("Requesting audio buffer block size of %d\n",ga->audioBufferSize);
#endif
       if( ioctl(ga->audio_fd, SNDCTL_DSP_SETFRAGMENT, &fragsize) == -1 )
       {
#ifndef __NOPRINTING__
          perror("SNDCTL_DSP_SETFRAGMENT");  
#endif
          ga->lastERR=ERR_HARDWARE_PARMS;
	  goto err;
       }
    }

    if( ioctl(ga->audio_fd, SNDCTL_DSP_SETFMT, &format) == -1 )
    {
#ifndef __NOPRINTING__
        perror("SNDCTL_DSP_SETFMT");  
#endif
        ga->lastERR=ERR_HARDWARE_BITS;
        goto err;
    }
    if( ioctl(ga->audio_fd, SNDCTL_DSP_STEREO, &stereo) == -1 )
    {
#ifndef __NOPRINTING__
        perror("SNDCTL_DSP_STEREO");  
#endif
        ga->lastERR=ERR_HARDWARE_CHAN;
        goto err;
    }
    if( ioctl(ga->audio_fd, SNDCTL_DSP_SPEED, &speed) == -1 )
    {
#ifndef __NOPRINTING__
        perror("SNDCTL_DSP_SPEED");  
#endif
        ga->lastERR=ERR_HARDWARE_FREQ;
        goto err;
    }

    if( ioctl(ga->audio_fd, SNDCTL_DSP_GETBLKSIZE, &fragsize) == -1 )
    {
#ifndef __NOPRINTING__
        perror("SNDCTL_DSP_GETBLKSIZE");  
#endif
        ga->lastERR=ERR_HARDWARE_PARMS;
        goto err;
    }
    ga->audioBufferSize=fragsize;  


    sssd_unpauseAudio(ga);

    return 0;


err:

    close( ga->audio_fd );
    ga->audio_fd = -1;
    return(ga->lastERR);  
}

