
#include "sssd.h"
#include "internals.h"

/*
   Stop gameaudio system: turn off all playing sounds, kill thread, close
   device.  Returns -1 on error.
*/

int sssd_stopAudio( struct sssdaudio* ga )
{
    int i;
	struct WinPlatformData * pdata;

   #ifndef __NOPRINTING__
   puts("sssd_stopAudio()");
   #endif

	pdata=(struct WinPlatformData *)ga->platformData;

    if( ga->audio_fd == -1 ) {
        ga->lastERR=ERR_NOT_INITIALIZED;
        return( ERR_NOT_INITIALIZED );
    }
    
    ga->lastERR = 0;

   if (ga->max_voices) {		// JH thread was not created if max_voices is 0
		/* Stop grabbing thread */
		LOCK_BUFFERS_NP(ga);
		ga->threadSignal=1;
		while(ga->threadSignal!=2) {
		UNLOCK_BUFFERS(ga);
		SLEEP_CALL(100<<10);
		LOCK_BUFFERS(ga);
		}
		SLEEP_CALL(100<<10);
		UNLOCK_BUFFERS(ga);
   }

	/* destroy Critical Section */
	EnterCriticalSection(&pdata->criticalSection);
	LeaveCriticalSection(&pdata->criticalSection);
	DeleteCriticalSection(&pdata->criticalSection);

	/* Free Sample Memory */
	sssd_freeSamples(ga);

	/* Stop Background playing */
    sssd_stopBackground(ga);

   /* Unprepare headers */
   for(i=0;i<ga->numAudioBuffers;i++) {
      waveOutUnprepareHeader(pdata->hWaveOut, &pdata->headers[i], sizeof(WAVEHDR));
   }
   
    /* Close device (try 4 times if uncessful) */
	i=5;
	while(i>0 && waveOutClose(pdata->hWaveOut)!=MMSYSERR_NOERROR) {SLEEP_CALL(100<<10);i--;}

   /* free play buffer */
    if(ga->playBuffer!=NULL) {
       free(ga->playBuffer);
       ga->playBuffer=NULL;
    }

    /* Free Sample structs */
    if(ga->samples!=NULL) {
       free(ga->samples);
       ga->samples=NULL;
    }

    /* Free Playing structs */
    if(ga->playing!=NULL) {
       free(ga->playing);
       ga->playing=NULL;
    }

    if(pdata->WinBuffer!=NULL) {
       free(pdata->WinBuffer);   
    }

	free(pdata->headers); 
    free(ga->platformData);

	/* destroy mutex */
   CloseHandle(ga->buffer_mutex);

	ga->audio_fd = -1;
    return( ga->lastERR );
}
